%define initscripts 20110502

Name:           upstart
Version:        1.2
Release:        4%{?dist}
Summary:        An event-driven init system

Group:          System Environment/Base
License:        GPLv2 and LGPLv2+
URL:            https://launchpad.net/upstart
Source0:        http://launchpad.net/upstart/1.x/%{version}/+download/upstart-%{version}.tar.gz
Source1:        init-system-dbus.conf
# These are taken from http://git.fedorahosted.org/git/?p=initscripts.git
Source2:        initjobs-%{initscripts}.tar.gz
# create missing files and directories according to /etc/tmpfiles.d/
Source3:        tmpfiles.conf
# fix selinux context on /run created and mounted by dracut
Source4:        fix-selinux-on-run.conf
# add /lib/upstart to shell PATH if upstart is running
Source5:        upstart.sh
Source6:        init.conf
Patch1:         upstart-telinit.patch
Patch2:         upstart-audit-events.patch
# set DEAD_PROCESS for dead process with pid in utmp table (#572199, #632568)
Patch3:         upstart-utmp.patch
Patch4:         upstart-reexec.patch
# allow job override files
Patch7:         upstart-override.patch
# add /lib/upstart to default PATH set by init process
Patch10:        upstart-lib-upstart.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:  autoconf, automake, gettext, audit-libs-devel, expat-devel
BuildRequires:  dbus-devel >= 1:1.2.16, libnih-devel >= 1.0.1
Conflicts:      initscripts < 9.12
Requires:       sysvinit-userspace /etc/rc.d/rc.sysinit

%description
Upstart is an event-based replacement for the /sbin/init daemon which
handles starting of tasks and services during boot, stopping them
during shutdown and supervising them while the system is running.

%prep
%setup -q -a 2
%patch1 -p1 -b .u
%patch2 -p1 -b .audit
%patch3 -p1 -b .utmp
%patch4 -p1 -b .reexec
%patch7 -p1 -b .override
%patch10 -p1 -b .lib-upstart

%build
autoreconf
%configure --sbindir=/lib/upstart --libdir=/%{_lib}
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

# Rename common SysV binaries and symlink them to allow parallel
# installation with systemd. We move the utility binaries into a
# subdirectory, so that program_name stays the same and Upstart still
# can check argv[0] properly in various places.
mkdir -p %{buildroot}/sbin/
ln -sf ../lib/upstart/init %{buildroot}/sbin/upstart
ln -sf ../lib/upstart/initctl %{buildroot}/sbin/initctl
ln -sf ../lib/upstart/start %{buildroot}/sbin/start
ln -sf ../lib/upstart/status %{buildroot}/sbin/status
ln -sf ../lib/upstart/stop %{buildroot}/sbin/stop
ln -sf ../lib/upstart/restart %{buildroot}/sbin/restart
ln -sf ../lib/upstart/reload %{buildroot}/sbin/reload
ln -sf reboot %{buildroot}/lib/upstart/poweroff
ln -sf reboot %{buildroot}/lib/upstart/halt
# Rename init.8.gz to upstart.7.gz (#644249)
mv %{buildroot}/%{_mandir}/man8/init.8 %{buildroot}/%{_mandir}/man7/upstart.7
# Remove these files due the conflicts with systemd
rm -f %{buildroot}/%{_mandir}/man8/{halt,init,poweroff,reboot,runlevel,shutdown,telinit}.*

# don't ship default jobs
rm -f %{buildroot}/%{_sysconfdir}/init/*
install -m 644 %{SOURCE1} %{buildroot}/%{_sysconfdir}/init/
install -m 644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/init/
install -m 644 %{SOURCE4} %{buildroot}/%{_sysconfdir}/init/
for file in initjobs-%{initscripts}/*.conf ; do
  install -m 644 $file %{buildroot}/%{_sysconfdir}/init/
done

mkdir -p -m 755 %{buildroot}/%{_sysconfdir}/profile.d/
install -m 644 %{SOURCE5} %{buildroot}/%{_sysconfdir}/profile.d/

install -m 644 %{SOURCE6} %{buildroot}/%{_sysconfdir}/init.conf

%find_lang %{name}

%check
#some tests fail in koji while pass in mock and local build
#to run make check use "--with check"
%if %{?_with_check:1}%{!?_with_check:0}
  make check
%endif

%clean
rm -rf %{buildroot}

%triggerpostun -- upstart < 0.6.0
[ -f /proc/1/exe -a -d /proc/1/root ] && kill -TERM 1

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS
%doc COPYING
%doc NEWS
%doc README
%doc TODO
%doc HACKING
%{_sysconfdir}/init/
%config(noreplace) %{_sysconfdir}/init.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/Upstart.conf
/sbin/upstart
/sbin/initctl
/sbin/start
/sbin/status
/sbin/stop
/sbin/restart
/sbin/reload
%dir /lib/upstart
/lib/upstart/init
/lib/upstart/initctl
/lib/upstart/poweroff
/lib/upstart/reboot
/lib/upstart/runlevel
/lib/upstart/shutdown
/lib/upstart/halt
/lib/upstart/start
/lib/upstart/status
/lib/upstart/stop
/lib/upstart/restart
/lib/upstart/telinit
/lib/upstart/reload
/etc/profile.d/upstart.sh
%{_mandir}/man5/init.5.gz
%{_mandir}/man5/inittab.5.gz
%{_mandir}/man7/control-alt-delete.7.gz
%{_mandir}/man7/keyboard-request.7.gz
%{_mandir}/man7/power-status-changed.7.gz
%{_mandir}/man7/runlevel.7.gz
%{_mandir}/man7/started.7.gz
%{_mandir}/man7/starting.7.gz
%{_mandir}/man7/startup.7.gz
%{_mandir}/man7/stopped.7.gz
%{_mandir}/man7/stopping.7.gz
%{_mandir}/man7/upstart.7.gz
%{_mandir}/man8/restart.8.gz
%{_mandir}/man8/initctl.8.gz
%{_mandir}/man8/start.8.gz
%{_mandir}/man8/status.8.gz
%{_mandir}/man8/stop.8.gz
%{_mandir}/man8/reload.8.gz

%changelog
* Wed May 25 2011 Petr Lautrbach <plautrba@redhat.com> 1.2-4
- drop Obsoletes: upstart-sysvinit (#707507)
- clean upstart-sysvinit stuff from spec file

* Fri May 13 2011 Petr Lautrbach <plautrba@redhat.com> 1.2-3
- add /etc/init.conf file

* Wed May 04 2011 Petr Lautrbach <plautrba@redhat.com> 1.2-2
- /run - fix selinux context and check for tmpfiles.d
- physically move binaries to /lib/upstart
- add /lib/upstart to default PATH

* Wed Mar 23 2011 Petr Lautrbach <plautrba@redhat.com> 1.2-1
- upgrade to 1.2
- update upstream URL

* Mon Mar 21 2011 Petr Lautrbach <plautrba@redhat.com> 1.1-1
- upgrade to 1.1 - https://launchpad.net/upstart/1.x/1.1
- allow job override files

* Thu Mar 03 2011 Petr Lautrbach <plautrba@redhat.com> 1.0-1
- upgrade to 1.0 - https://launchpad.net/upstart/1.x/1.0

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Dec 17 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.7-1
- upgrade to 0.6.7

* Mon Dec 06 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.6-4
- Stop tty and serial also on runlevel 's'

* Fri Nov 26 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.6-3
- create missing files and directories according to /etc/init/tmpfiles.conf

* Tue Nov 16 2010 Bill Nottingham <notting@redhat.com> 0.6.6-2
- require /etc/rc.d/rc.sysinit to pull in new initscripts-legacy package where needed

* Wed Oct 27 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.6-1
- upgrade to 0.6.6
- boot jobs source renamed

* Tue Oct 26 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.5-14
- send close fd command to shell first (#646894)

* Tue Oct 19 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.5-13
- Rename init(8) to upstart(7) (#644249)

* Thu Oct 14 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.5-12
- Disable -sysvinit to avoid conflicts with systemd (#635323)

* Wed Sep 29 2010 jkeating - 0.6.5-11
- Rebuilt for gcc bug 634757

* Fri Sep 24 2010 Bill Nottingham <notting@redhat.com> 0.6.5-10
- merge in basic boot jobs here (#637099)

* Tue Sep 21 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.5-9
- set DEAD_PROCESS for dead process with pid in utmp table (#572199, #632568)
- exit shutdown with nonzero exitcode when fails shutdown

* Fri Sep 17 2010 Bill Nottingham <notting@redhat.com> - 0.6.5-8
- ensure F15 version is newer than F-14

* Sat Jul 24 2010 Casey Dahlin <cdahlin@redhat.com> - 0.6.5-7
- Make upgrades work correctly now that -sysvinit is split off

* Sat Jul 24 2010 Lennart Poettering <lpoetter@redhat.com> - 0.6.5-6
- Split off -sysvinit to make Upstart parallel installable with systemd

* Tue May 4 2010 Bill Nottingham <notting@redhat.com> 0.6.5-5
- re-add SIGTERM handler so restart on shutdown works, avoiding dirty inodes (#576662)

* Tue Apr 6 2010 Casey Dahlin <cdahlin@redhat.com> 0.6.5-4
- Reload init after install

* Wed Feb 24 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.5-3
- run "make check" only with --with check

* Fri Feb 19 2010 Casey Dahlin <cdahlin@redhat.com> 0.6.5-2
- be more specific about which libnih we need.

* Wed Feb 17 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.5-1
- upgrade to 0.6.5

* Fri Jan 29 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.3-7
- add SIGUSR1 handler and init-system-dbus.conf (#559660)

* Sun Jan 17 2010 Dennis Gilmore <dennis@ausil.us> - 0.6.3-6
- add patch from upstream fixing sparc alignment issues

* Mon Jan 11 2010 Petr Lautrbach <plautrba@redhat.com> 0.6.3-5
- License changed to GPLv2 and LGPLv2+

* Wed Dec 16 2009 Petr Lautrbach <plautrba@redhat.com> 0.6.3-4
- audit events patch rebased for 0.6 (#470661)

* Thu Dec  3 2009 Bill Nottingham <notting@redhat.com> 0.6.3-3
- make 'telinit u' a no-op, temporarily

* Fri Nov 27 2009 Petr Lautrbach <plautrba@redhat.com> 0.6.3-2
- Removed tests which fail in koji

* Fri Nov 20 2009 Casey Dahlin <cdahlin@redhat.com> - 0.6.3-1
- Upgrade to 0.6.3

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 0.3.11-3
- rebuilt with new audit

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jun 22 2009 Petr Lautrbach <plautrba@redhat.com> - 0.3.11-1
- Update to 0.3.11

* Mon Apr 27 2009 Bill Nottingham <notting@redhat.com> - 0.3.9-24
- Apply the audit patch correctly (#470661)

* Fri Apr 3 2009 Casey Dahlin <cdahlin@redhat.com> - 0.3.9-23
- Add audit events patch from Steve Grubb <sgrubb@redhat.com> (Bug #470661)

* Fri Jan 23 2009 Casey Dahlin <cdahlin@redhat.com> - 0.3.9-22
- Re-add 'telinit u' support along with patch to fix it (#450488). Patch due to
  <pspencer@fields.utoronto.ca>

* Mon Jan 12 2009 Bill Nottingham <notting@redhat.com> - 0.3.9-21
- Remove 'telinit u' support as it is broken (#450488, <cjdahlin@ncsu.edu>)

* Fri Apr 25 2008 Bill Nottingham <notting@redhat.com> - 0.3.9-19
- with the merge of event-compat-sysv, move the sysvinit obsoletes/provides here

* Thu Apr 24 2008 Bill Nottingham <notting@redhat.com> - 0.3.9-18
- fix some man page typos (#444008, <archimerged@gmail.com>)

* Wed Apr 09 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-17
- Added list of stock events to events(5)

* Tue Apr 08 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-16
- Add telinit u support

* Fri Apr 04 2008 Bill Nottingham <notting@redhat.com> - 0.3.9-15
- Add a events(5) manpage that describes event syntax

* Thu Apr 03 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-14
- Change bug report email address to fedora-devel-list@redhat.com

* Thu Mar 14 2008 Bill Nottingham <notting@redhat.com> - 0.3.9-13
- Ignore rpm temporary files of the foo;<somehex> format
- Make ignores of .rpm{new,orig,save} match only at the end of the name

* Wed Mar 13 2008 Bill Nottingham <notting@redhat.com> - 0.3.9-12
- forgot about rpmorig too (ugh)

* Wed Mar 13 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-11
- Make logd a noreplace

* Wed Mar 13 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-10
- Add patch to ignore .rpm{new,save} files

* Sun Mar 03 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-9
- Remove automake dependency, build Makefile.in changes into patch

* Sun Mar 03 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-8
- Run automake after patching

* Sun Mar 03 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-7
- Added BuildRequires: automake

* Sun Mar 03 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-6
- Added patch to allow runtime tty changes

* Fri Feb 15 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-5
- Added patch to imply --force on runlevels 0 and 6

* Wed Feb 06 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-4
- Patched for GCC 4.3

* Thu Jan 31 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-3
- Added AUTHORS, COPYING, etc.
- Made config --libdir option relative

* Mon Jan 21 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-2
- Remove libnih and libupstart

* Sun Jan 13 2008 Casey Dahlin <cjdahlin@ncsu.edu> - 0.3.9-1
- Initial packaging
